# Module

[Licensecheck Index](../README.md#licensecheck-index) / [Licensecheck](./index.md#licensecheck) / Module

> Auto-generated documentation for [licensecheck.__main__](../../../licensecheck/__main__.py) module.
- [Module](#module)
